==> mod_etherpadlite_moodle45_2024071101.zip: etherpadlite/CHANGES.md <==
moodle-mod_etherpadlite
=======================

Changes
-------

### v4.4.3
* Improved URL checking in the test tool, suitable for installations in a subdirectory
* Apply moodle coding style

### v4.4.2
* Introduce dedicated connection testing tool by André Menrath (#79)
* Fix unchecked check_ssl option not being honored by Ilja Rozhko
* Fix unittest mod_etherpadlite

### v4.4.1
* Tint monologo icon with dark grey as standard, resolves (#77)

### v4.4

* 2024-07-10 -   Requires now Moodle 4.4
* 2024-07-10 -   Optimize github actions
* 2024-07-10 -   Fix some smaller coding style issues
* 2024-07-10 -   All recent Moodle and PHP versions (Luca Bösch) #75
* 2024-05-26 -   Smaller monologo icon for Moodle ≥ 4.4 (Luca Bösch) #74

### v4.3.1

* 2023-11-09 -   Fix client construtor #73 (Thank to Daniil Fajnberg)

### v4.3

* 2023-10-15 -  Add close button to the etherpad page
* 2023-10-15 -  Optimize error handling
* 2023-10-15 -  Adjust coding style to new rules

### v4.2-r5

* 2023-05-10 -  Added provider.php to pass test (Thanks to Karl Michael Reyes from Catalyst IT Canada LTD)

### v4.2-r4

* 2023-06-12 -  add new settings to adjust CURLOPT_CONNECTTIMEOUT and CURLOPT_TIMEOUT (Thanks to Vincent Schneider)

### v4.2-r3

* 2023-05-10 -  add missing slash

### v4.2-r2

* 2023-05-10 -  Fix require_once into stable path

### v4.2-r1

* 2023-04-27 -  Switch to testing mode if etherpadlite|url is empty

### v4.0-r7

* 2022-12-15 -  Add support for course reset
* 2022-12-15 -  Add backup/restore for group pads

### v4.0-r6

* 2022-11-16 -  Add testing support for behat and phpunit test
* 2022-11-16 -  Add CHANGES.md

### v4.0-r5

* 2022-11-14 -  fix upgrade.php.
* 2022-11-07 -  Fix event classes abstraction.

### v4.0-r5

* 2022-11-07 -  Fix coding style and add phpdoc comments.

### v4.0-r4

* 2022-11-03 -  Add new monologo.

### v4.0-r1

* 2022-05-14 -  First stable version for Moodle 4.0.

### v4.0-beta2

* 2022-04-14 -  Seperate Groups Feature (#34).

### v4.0-beta1

* 2022-03-14 -  Start optimizing for Moodle 4.0.

==> mod_etherpadlite_moodle51_2025041602.zip: etherpadlite/CHANGES.md <==
moodle-mod_etherpadlite
=======================

Changes
-------

### v5.0.3
* Activity information for Moodle 5.1 activity chooser (#87 and #88)
* Improved URL checking in the test tool, suitable for installations in a subdirectory

### v5.0.2
* Support course overview - thanks to Luca Bösch (#85 and #86)
* Comply to Moodle Code checker - thanks to Luca Bösch (#86)

### v5.0.1
* Introduce dedicated connection testing tool by André Menrath (#79)
* Fix unchecked check_ssl option not being honored by Ilja Rozhko
* Fix unittest mod_etherpadlite

### v5.0
* Tint monologo icon with dark grey as standard, resolves (#77)
* adjust code for Moodle 5.0 using Bootstrap 5.3

### v4.4

* 2024-07-10 -   Requires now Moodle 4.4
* 2024-07-10 -   Optimize github actions
* 2024-07-10 -   Fix some smaller coding style issues
* 2024-07-10 -   All recent Moodle and PHP versions (Luca Bösch) #75
* 2024-05-26 -   Smaller monologo icon for Moodle ≥ 4.4 (Luca Bösch) #74

### v4.3.1

* 2023-11-09 -   Fix client construtor #73 (Thank to Daniil Fajnberg)

### v4.3

* 2023-10-15 -  Add close button to the etherpad page
* 2023-10-15 -  Optimize error handling
* 2023-10-15 -  Adjust coding style to new rules

### v4.2-r5

* 2023-05-10 -  Added provider.php to pass test (Thanks to Karl Michael Reyes from Catalyst IT Canada LTD)

### v4.2-r4

* 2023-06-12 -  add new settings to adjust CURLOPT_CONNECTTIMEOUT and CURLOPT_TIMEOUT (Thanks to Vincent Schneider)

### v4.2-r3

* 2023-05-10 -  add missing slash

### v4.2-r2

* 2023-05-10 -  Fix require_once into stable path

### v4.2-r1

* 2023-04-27 -  Switch to testing mode if etherpadlite|url is empty

### v4.0-r7

* 2022-12-15 -  Add support for course reset
* 2022-12-15 -  Add backup/restore for group pads

### v4.0-r6

* 2022-11-16 -  Add testing support for behat and phpunit test
* 2022-11-16 -  Add CHANGES.md

### v4.0-r5

* 2022-11-14 -  fix upgrade.php.
* 2022-11-07 -  Fix event classes abstraction.

### v4.0-r5

* 2022-11-07 -  Fix coding style and add phpdoc comments.

### v4.0-r4

* 2022-11-03 -  Add new monologo.

### v4.0-r1

* 2022-05-14 -  First stable version for Moodle 4.0.

### v4.0-beta2

* 2022-04-14 -  Seperate Groups Feature (#34).

### v4.0-beta1

* 2022-03-14 -  Start optimizing for Moodle 4.0.
